# -*- coding: utf-8 -*-
"""Cisco Identity Services Engine AuthorizationProfile API wrapper.

Copyright (c) 2021 Cisco and/or its affiliates.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


from __future__ import (
    absolute_import,
    division,
    print_function,
    unicode_literals,
)

from builtins import *

from past.builtins import basestring

from ...restsession import RestSession
from ...utils import (
    check_type,
    dict_from_items_with_values,
    apply_path_params,
    dict_of_str,
)
from ...pagination import get_next_page


class AuthorizationProfile(object):
    """Identity Services Engine AuthorizationProfile API (version: 3.0.0).

    Wraps the Identity Services Engine AuthorizationProfile
    API and exposes the API as native Python
    methods that return native Python objects.

    | Authorization Profile API allows the client to add, delete, update, search and perform actions on authorization profiles.

    **Revision History**

    +------------+--------------------+-------------------+---------------------------------------------+-----------------------+---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+
    | Revision # | Resource   Version | Cisco ISE Version | Description                                 | Revision Modification | Revision Modification                                                                                                                                                                                         |
    +------------+--------------------+-------------------+---------------------------------------------+-----------------------+---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+
    |            |                    |                   |                                             | Attribute             | Description                                                                                                                                                                                                   |
    +------------+--------------------+-------------------+---------------------------------------------+-----------------------+---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+
    | 0          | 1.0                | 2.2               | Initial Cisco ISE Version                   |                       |                                                                                                                                                                                                               |
    +------------+--------------------+-------------------+---------------------------------------------+-----------------------+---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+
    | 1          | 1.1                | 2.3               | Support new attributes under common   tasks | accessType            | Added Attribute 'accessType'. Default value:'ACCESS_ACCEPT',   additional values: 'ACCESS_REJECT'                                                                                                             |
    +------------+--------------------+-------------------+---------------------------------------------+-----------------------+---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+
    |            |                    |                   |                                             | authzProfileType      | Added   Attribute 'authzProfileType' to differentiate between types of authorization   profiles. Default value:'SWITCH' (used for Standard Authorization Profiles)   , additional values:'TACACS', 'TRUSTSEC' |
    +------------+--------------------+-------------------+---------------------------------------------+-----------------------+---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+
    |            |                    |                   |                                             | reauth                | Added   Attribute 'reauth' to determine reauthentication policy                                                                                                                                               |
    +------------+--------------------+-------------------+---------------------------------------------+-----------------------+---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+
    |            |                    |                   |                                             | webRedirection        | Added   Attribute 'webRedirection' to support selection of portal redirection                                                                                                                                 |
    +------------+--------------------+-------------------+---------------------------------------------+-----------------------+---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+
    |            |                    |                   |                                             | acl                   | Added String Attribute 'acl'                                                                                                                                                                                  |
    +------------+--------------------+-------------------+---------------------------------------------+-----------------------+---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+
    |            |                    |                   |                                             | trackMovement         | Added Boolean Attribute   'trackMovement'                                                                                                                                                                     |
    +------------+--------------------+-------------------+---------------------------------------------+-----------------------+---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+

    |

    **Resource Definition**

    +--------------------------------------+-----------+--------------+----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+--------------------+----------------------------------+
    | **Attribute**                        | **Type**  | **Required** | **Description**                                                                                                                                                                                                | **Default Values** | **Example Values**               |
    +--------------------------------------+-----------+--------------+----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+--------------------+----------------------------------+
    | name                                 | String    | Yes          | Resource Name                                                                                                                                                                                                  |                    | name                             |
    +--------------------------------------+-----------+--------------+----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+--------------------+----------------------------------+
    | id                                   | String    | No           | Resource UUID value                                                                                                                                                                                            |                    | id                               |
    +--------------------------------------+-----------+--------------+----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+--------------------+----------------------------------+
    | description                          | String    | No           |                                                                                                                                                                                                                |                    | description                      |
    +--------------------------------------+-----------+--------------+----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+--------------------+----------------------------------+
    | vlan                                 | List      | No           |                                                                                                                                                                                                                |                    |                                  |
    +--------------------------------------+-----------+--------------+----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+--------------------+----------------------------------+
    | - nameID                             | String    | Yes          |                                                                                                                                                                                                                |                    | vlanName                         |
    +--------------------------------------+-----------+--------------+----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+--------------------+----------------------------------+
    | - tagID                              | Integer   | Yes          | Valid range is 0-31                                                                                                                                                                                            |                    | 1                                |
    +--------------------------------------+-----------+--------------+----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+--------------------+----------------------------------+
    | airespaceACL                         | String    | No           |                                                                                                                                                                                                                |                    | ACL                              |
    +--------------------------------------+-----------+--------------+----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+--------------------+----------------------------------+
    | webRedirection                       | List      | No           |                                                                                                                                                                                                                |                    |                                  |
    +--------------------------------------+-----------+--------------+----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+--------------------+----------------------------------+
    | - WebRedirectionType                 | String    | Yes          | Value MUST be one of the following:CentralizedWebAuth, HotSpot, NativeSupplicanProvisioning, ClientProvisioning. The WebRedirectionType must fit the portalName                                                |                    | CentralizedWebAuth               |
    +--------------------------------------+-----------+--------------+----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+--------------------+----------------------------------+
    | - acl                                | String    | Yes          |                                                                                                                                                                                                                |                    | acl                              |
    +--------------------------------------+-----------+--------------+----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+--------------------+----------------------------------+
    | - portalName                         | String    | Yes          | A portal that exist in the DB and fits the WebRedirectionType                                                                                                                                                  |                    | Sponsored Guest Portal (default) |
    +--------------------------------------+-----------+--------------+----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+--------------------+----------------------------------+
    | - staticIPHostNameFQDN               | String    | No           |                                                                                                                                                                                                                |                    | 10.56.54.200                     |
    +--------------------------------------+-----------+--------------+----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+--------------------+----------------------------------+
    | - displayCertificatesRenewalMessages | Boolean   | No           | The displayCertificatesRenewalMessages is mandatory when 'WebRedirectionType' value is 'CentralizedWebAuth'. For all other 'WebRedirectionType' values the field must be ignored                               | true               |                                  |
    +--------------------------------------+-----------+--------------+----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+--------------------+----------------------------------+
    | accessType                           | Enum      | No           | Allowed Values: ACCESS_ACCEPT, ACCESS_REJECT                                                                                                                                                                   | ACCESS_ACCEPT      |                                  |
    +--------------------------------------+-----------+--------------+----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+--------------------+----------------------------------+
    | authzProfileType                     | Enum      | No           | Allowed Values: SWITCH, TRUSTSEC, TACACS                                                                                                                                                                       | SWITCH             |                                  |
    +--------------------------------------+-----------+--------------+----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+--------------------+----------------------------------+
    |                                      |           |              | SWITCH is used for Standard Authorization Profiles                                                                                                                                                             |                    |                                  |
    +--------------------------------------+-----------+--------------+----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+--------------------+----------------------------------+
    | profileName                          | String    | No           |                                                                                                                                                                                                                | Cisco              |                                  |
    +--------------------------------------+-----------+--------------+----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+--------------------+----------------------------------+
    | acl                                  | String    | No           |                                                                                                                                                                                                                |                    | aclfilter                        |
    +--------------------------------------+-----------+--------------+----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+--------------------+----------------------------------+
    | daclName                             | String    | No           |                                                                                                                                                                                                                |                    | PERMIT_ALL_IPV4_TRAFFIC          |
    +--------------------------------------+-----------+--------------+----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+--------------------+----------------------------------+
    | autoSmartPort                        | String    | No           |                                                                                                                                                                                                                |                    | autoSmartPort                    |
    +--------------------------------------+-----------+--------------+----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+--------------------+----------------------------------+
    | interfaceTemplate                    | Sring     | No           |                                                                                                                                                                                                                |                    | interfaceTemplate                |
    +--------------------------------------+-----------+--------------+----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+--------------------+----------------------------------+
    | ipv6ACLFilter                        | String    | No           |                                                                                                                                                                                                                |                    | ipv6ACLFilter                    |
    +--------------------------------------+-----------+--------------+----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+--------------------+----------------------------------+
    | avcProfile                           | String    | No           |                                                                                                                                                                                                                |                    | avcProfile                       |
    +--------------------------------------+-----------+--------------+----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+--------------------+----------------------------------+
    | asaVpn                               | String    | No           |                                                                                                                                                                                                                |                    | Cisco:cisco-call-type            |
    +--------------------------------------+-----------+--------------+----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+--------------------+----------------------------------+
    | trackMovement                        | Boolean   | No           |                                                                                                                                                                                                                | false              |                                  |
    +--------------------------------------+-----------+--------------+----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+--------------------+----------------------------------+
    | serviceTemplate                      | Boolean   | No           |                                                                                                                                                                                                                | false              |                                  |
    +--------------------------------------+-----------+--------------+----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+--------------------+----------------------------------+
    | easywiredSessionCandidate            | Boolean   | No           |                                                                                                                                                                                                                | false              |                                  |
    +--------------------------------------+-----------+--------------+----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+--------------------+----------------------------------+
    | voiceDomainPermission                | Boolean   | No           |                                                                                                                                                                                                                | false              |                                  |
    +--------------------------------------+-----------+--------------+----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+--------------------+----------------------------------+
    | neat                                 | Boolean   | No           |                                                                                                                                                                                                                | false              |                                  |
    +--------------------------------------+-----------+--------------+----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+--------------------+----------------------------------+
    | webAuth                              | Boolean   | No           |                                                                                                                                                                                                                | false              |                                  |
    +--------------------------------------+-----------+--------------+----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+--------------------+----------------------------------+
    | macSecPolicy                         | Enum      | No           | Allowed Values: MUST_SECURE, MUST_NOT_SECURE, SHOULD_SECURE                                                                                                                                                    |                    | MUST_SECURE                      |
    +--------------------------------------+-----------+--------------+----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+--------------------+----------------------------------+
    | reauth                               | List      | No           |                                                                                                                                                                                                                |                    |                                  |
    +--------------------------------------+-----------+--------------+----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+--------------------+----------------------------------+
    | - connectivity                       | Enum      | Yes          | Allowed Values: DEFAULT, RADIUS_REQUEST                                                                                                                                                                        |                    | RADIUS_REQUEST                   |
    +--------------------------------------+-----------+--------------+----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+--------------------+----------------------------------+
    | - timer                              | Integer   | Yes          | Valid range is 1-65535                                                                                                                                                                                         |                    | 1800                             |
    +--------------------------------------+-----------+--------------+----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+--------------------+----------------------------------+
    | advancedAttributes                   | List      | No           |                                                                                                                                                                                                                |                    |                                  |
    +--------------------------------------+-----------+--------------+----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+--------------------+----------------------------------+
    | - leftHandSideDictionaryAttribue     | List      | Yes          | Left side Dictionary and Attribute                                                                                                                                                                             |                    |                                  |
    +--------------------------------------+-----------+--------------+----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+--------------------+----------------------------------+
    |   - dictionaryName                   | String    | Yes          | Dictionary name                                                                                                                                                                                                |                    |                                  |
    +--------------------------------------+-----------+--------------+----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+--------------------+----------------------------------+
    |   - attributeName                    | String    | Yes          | Attribute name                                                                                                                                                                                                 |                    |                                  |
    +--------------------------------------+-----------+--------------+----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+--------------------+----------------------------------+
    | - rightHandSideAttribueValue         | LIst      | Yes          | Attribute value can be of type AttributeValue or AdvancedDictionaryAttribute. For AttributeValue the value is String, For AdvancedDictionaryAttribute the value is dictionaryName and attributeName properties |                    |                                  |
    +--------------------------------------+-----------+--------------+----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+--------------------+----------------------------------+
    | ipv6DaclName                         | String    | No           |                                                                                                                                                                                                                |                    | PERMIT_ALL_IPV6_TRAFFIC          |
    +--------------------------------------+-----------+--------------+----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+--------------------+----------------------------------+
    | airespaceIPv6ACL                     | String    | No           |                                                                                                                                                                                                                |                    | ACL6                             |
    +--------------------------------------+-----------+--------------+----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+--------------------+----------------------------------+

    """

    def __init__(self, session, object_factory, request_validator):
        """Initialize a new AuthorizationProfile
        object with the provided RestSession.

        Args:
            session(RestSession): The RESTful session object to be used for
                API calls to the Identity Services Engine service.

        Raises:
            TypeError: If the parameter types are incorrect.

        """
        check_type(session, RestSession)

        super(AuthorizationProfile, self).__init__()

        self._session = session
        self._object_factory = object_factory
        self._request_validator = request_validator

    def get_authorization_profile_by_name(self,
                                          name,
                                          headers=None,
                                          **query_parameters):
        """This API allows the client to get an authorization profile by
        name.

        Args:
            name(basestring): name path parameter.
            headers(dict): Dictionary of HTTP Headers to send with the Request
                .
            **query_parameters: Additional query parameters (provides
                support for parameters that may be added in the future).

        Returns:

            RestResponse: REST response with following properties:

              - headers(MyDict): response headers.
              - response(MyDict): response body as a MyDict object. Access the object's properties by using the dot notation
                or the bracket notation.
              - content(bytes): representation of the request's response
              - text(str): representation of the request's response

        Raises:
            TypeError: If the parameter types are incorrect.
            MalformedRequest: If the request body created is invalid.
            ApiError: If the Identity Services Engine cloud returns an error.
        """
        check_type(headers, dict)

        if headers is not None:
            if 'Content-Type' in headers:
                check_type(headers.get('Content-Type'),
                           basestring, may_be_none=False)
            if 'Accept' in headers:
                check_type(headers.get('Accept'),
                           basestring, may_be_none=False)
            if 'ERS-Media-Type' in headers:
                check_type(headers.get('ERS-Media-Type'),
                           basestring)
            if 'X-CSRF-Token' in headers:
                check_type(headers.get('X-CSRF-Token'),
                           basestring)

        with_custom_headers = False
        _headers = self._session.headers or {}
        if headers:
            _headers.update(dict_of_str(headers))
            with_custom_headers = True
        check_type(name, basestring,
                   may_be_none=False)

        _params = {
        }
        _params.update(query_parameters)
        _params = dict_from_items_with_values(_params)

        path_params = {
            'name': name,
        }

        e_url = ('/ers/config/authorizationprofile/name/{name}')
        endpoint_full_url = apply_path_params(e_url, path_params)
        if with_custom_headers:
            _api_response = self._session.get(endpoint_full_url, params=_params,
                                              headers=_headers)
        else:
            _api_response = self._session.get(endpoint_full_url, params=_params)

        return self._object_factory('bpm_acf0372068885036baee3c4524638f31_v3_0_0', _api_response)

    def get_by_name(self,
                    name,
                    headers=None,
                    **query_parameters):
        """Alias for `get_authorization_profile_by_name <#ciscoisesdk.
        api.v3_0_0.authorization_profile.
        AuthorizationProfile.get_authorization_profile_by_name>`_
        """
        return self.get_authorization_profile_by_name(
            name=name,
            headers=headers,
            **query_parameters
        )

    def get_authorization_profile_by_id(self,
                                        id,
                                        headers=None,
                                        **query_parameters):
        """This API allows the client to get an authorization profile by
        ID.

        Args:
            id(basestring): id path parameter.
            headers(dict): Dictionary of HTTP Headers to send with the Request
                .
            **query_parameters: Additional query parameters (provides
                support for parameters that may be added in the future).

        Returns:

            RestResponse: REST response with following properties:

              - headers(MyDict): response headers.
              - response(MyDict): response body as a MyDict object. Access the object's properties by using the dot notation
                or the bracket notation.
              - content(bytes): representation of the request's response
              - text(str): representation of the request's response

        Raises:
            TypeError: If the parameter types are incorrect.
            MalformedRequest: If the request body created is invalid.
            ApiError: If the Identity Services Engine cloud returns an error.
        """
        check_type(headers, dict)

        if headers is not None:
            if 'Content-Type' in headers:
                check_type(headers.get('Content-Type'),
                           basestring, may_be_none=False)
            if 'Accept' in headers:
                check_type(headers.get('Accept'),
                           basestring, may_be_none=False)
            if 'ERS-Media-Type' in headers:
                check_type(headers.get('ERS-Media-Type'),
                           basestring)
            if 'X-CSRF-Token' in headers:
                check_type(headers.get('X-CSRF-Token'),
                           basestring)

        with_custom_headers = False
        _headers = self._session.headers or {}
        if headers:
            _headers.update(dict_of_str(headers))
            with_custom_headers = True
        check_type(id, basestring,
                   may_be_none=False)

        _params = {
        }
        _params.update(query_parameters)
        _params = dict_from_items_with_values(_params)

        path_params = {
            'id': id,
        }

        e_url = ('/ers/config/authorizationprofile/{id}')
        endpoint_full_url = apply_path_params(e_url, path_params)
        if with_custom_headers:
            _api_response = self._session.get(endpoint_full_url, params=_params,
                                              headers=_headers)
        else:
            _api_response = self._session.get(endpoint_full_url, params=_params)

        return self._object_factory('bpm_a69c7f1ad54e5e9cae1f871e19eed61b_v3_0_0', _api_response)

    def get_by_id(self,
                  id,
                  headers=None,
                  **query_parameters):
        """Alias for `get_authorization_profile_by_id <#ciscoisesdk.
        api.v3_0_0.authorization_profile.
        AuthorizationProfile.get_authorization_profile_by_id>`_
        """
        return self.get_authorization_profile_by_id(
            id=id,
            headers=headers,
            **query_parameters
        )

    def update_authorization_profile_by_id(self,
                                           id,
                                           access_type=None,
                                           acl=None,
                                           advanced_attributes=None,
                                           agentless_posture=None,
                                           airespace_acl=None,
                                           airespace_ipv6_acl=None,
                                           asa_vpn=None,
                                           authz_profile_type=None,
                                           auto_smart_port=None,
                                           avc_profile=None,
                                           dacl_name=None,
                                           description=None,
                                           easywired_session_candidate=None,
                                           interface_template=None,
                                           ipv6_acl_filter=None,
                                           ipv6_dacl_name=None,
                                           mac_sec_policy=None,
                                           name=None,
                                           neat=None,
                                           profile_name=None,
                                           reauth=None,
                                           service_template=None,
                                           track_movement=None,
                                           vlan=None,
                                           voice_domain_permission=None,
                                           web_auth=None,
                                           web_redirection=None,
                                           headers=None,
                                           payload=None,
                                           active_validation=True,
                                           **query_parameters):
        """This API allows the client to update an authorization profile.

        Args:
            access_type(string): Allowed Values: ACCESS_ACCEPT,
                ACCESS_REJECT, property of the request
                body.
            acl(string): acl, property of the request body.
            advanced_attributes(list): advancedAttributes, property
                of the request body (list of objects).
            agentless_posture(boolean): agentlessPosture, property
                of the request body.
            airespace_acl(string): airespaceACL, property of the
                request body.
            airespace_ipv6_acl(string): airespaceIPv6ACL, property
                of the request body.
            asa_vpn(string): asaVpn, property of the request body.
            authz_profile_type(string): Allowed Values: SWITCH,
                TRUSTSEC, TACACS SWITCH is used for
                Standard Authorization Profiles,
                property of the request body.
            auto_smart_port(string): autoSmartPort, property of the
                request body.
            avc_profile(string): avcProfile, property of the request
                body.
            dacl_name(string): daclName, property of the request
                body.
            description(string): description, property of the
                request body.
            easywired_session_candidate(boolean):
                easywiredSessionCandidate, property of
                the request body.
            id(string): Resource UUID value, property of the request
                body.
            interface_template(string): interfaceTemplate, property
                of the request body.
            ipv6_acl_filter(string): ipv6ACLFilter, property of the
                request body.
            ipv6_dacl_name(string): ipv6DaclName, property of the
                request body.
            mac_sec_policy(string): Allowed Values: MUST_SECURE,
                MUST_NOT_SECURE, SHOULD_SECURE, property
                of the request body.
            name(string): Resource Name, property of the request
                body.
            neat(boolean): neat, property of the request body.
            profile_name(string): profileName, property of the
                request body.
            reauth(object): reauth, property of the request body.
            service_template(boolean): serviceTemplate, property of
                the request body.
            track_movement(boolean): trackMovement, property of the
                request body.
            vlan(object): vlan, property of the request body.
            voice_domain_permission(boolean): voiceDomainPermission,
                property of the request body.
            web_auth(boolean): webAuth, property of the request
                body.
            web_redirection(object): webRedirection, property of the
                request body.
            id(basestring): id path parameter.
            headers(dict): Dictionary of HTTP Headers to send with the Request
                .
            payload(dict): A JSON serializable Python object to send in the
                body of the Request.
            active_validation(bool): Enable/Disable payload validation.
                Defaults to True.
            **query_parameters: Additional query parameters (provides
                support for parameters that may be added in the future).

        Returns:

            RestResponse: REST response with following properties:

              - headers(MyDict): response headers.
              - response(MyDict): response body as a MyDict object. Access the object's properties by using the dot notation
                or the bracket notation.
              - content(bytes): representation of the request's response
              - text(str): representation of the request's response

        Raises:
            TypeError: If the parameter types are incorrect.
            MalformedRequest: If the request body created is invalid.
            ApiError: If the Identity Services Engine cloud returns an error.
        """
        check_type(headers, dict)

        if headers is not None:
            if 'Content-Type' in headers:
                check_type(headers.get('Content-Type'),
                           basestring, may_be_none=False)
            if 'Accept' in headers:
                check_type(headers.get('Accept'),
                           basestring, may_be_none=False)
            if 'ERS-Media-Type' in headers:
                check_type(headers.get('ERS-Media-Type'),
                           basestring)
            if 'X-CSRF-Token' in headers:
                check_type(headers.get('X-CSRF-Token'),
                           basestring)

        with_custom_headers = False
        _headers = self._session.headers or {}
        if headers:
            _headers.update(dict_of_str(headers))
            with_custom_headers = True
        is_xml_payload = 'application/xml' in _headers.get('Content-Type', [])
        if active_validation and is_xml_payload:
            check_type(payload, basestring)
        if active_validation and not is_xml_payload:
            check_type(payload, dict)
        check_type(id, basestring,
                   may_be_none=False)

        _params = {
        }
        _params.update(query_parameters)
        _params = dict_from_items_with_values(_params)

        path_params = {
            'id': id,
        }
        if is_xml_payload:
            _payload = payload
        else:
            _tmp_payload = {
                'id':
                    id,
                'name':
                    name,
                'description':
                    description,
                'advancedAttributes':
                    advanced_attributes,
                'accessType':
                    access_type,
                'authzProfileType':
                    authz_profile_type,
                'vlan':
                    vlan,
                'reauth':
                    reauth,
                'airespaceACL':
                    airespace_acl,
                'airespaceIPv6ACL':
                    airespace_ipv6_acl,
                'webRedirection':
                    web_redirection,
                'acl':
                    acl,
                'trackMovement':
                    track_movement,
                'agentlessPosture':
                    agentless_posture,
                'serviceTemplate':
                    service_template,
                'easywiredSessionCandidate':
                    easywired_session_candidate,
                'daclName':
                    dacl_name,
                'voiceDomainPermission':
                    voice_domain_permission,
                'neat':
                    neat,
                'webAuth':
                    web_auth,
                'autoSmartPort':
                    auto_smart_port,
                'interfaceTemplate':
                    interface_template,
                'ipv6ACLFilter':
                    ipv6_acl_filter,
                'avcProfile':
                    avc_profile,
                'macSecPolicy':
                    mac_sec_policy,
                'asaVpn':
                    asa_vpn,
                'profileName':
                    profile_name,
                'ipv6DaclName':
                    ipv6_dacl_name,
            }
            _payload = {
                'AuthorizationProfile': dict_from_items_with_values(_tmp_payload)
            }
            _payload.update(payload or {})
            _payload = dict_from_items_with_values(_payload)
        if active_validation and not is_xml_payload:
            self._request_validator('jsd_cb9f26e93655e7d89995b172f6fd97f_v3_0_0')\
                .validate(_payload)

        e_url = ('/ers/config/authorizationprofile/{id}')
        endpoint_full_url = apply_path_params(e_url, path_params)

        request_params = {'data': _payload} if is_xml_payload else {'json': _payload}
        if with_custom_headers:
            _api_response = self._session.put(endpoint_full_url, params=_params,
                                              headers=_headers,
                                              **request_params)

        else:
            _api_response = self._session.put(endpoint_full_url, params=_params,
                                              **request_params)

        return self._object_factory('bpm_cb9f26e93655e7d89995b172f6fd97f_v3_0_0', _api_response)

    def update_by_id(self,
                     id,
                     access_type=None,
                     acl=None,
                     advanced_attributes=None,
                     agentless_posture=None,
                     airespace_acl=None,
                     airespace_ipv6_acl=None,
                     asa_vpn=None,
                     authz_profile_type=None,
                     auto_smart_port=None,
                     avc_profile=None,
                     dacl_name=None,
                     description=None,
                     easywired_session_candidate=None,
                     interface_template=None,
                     ipv6_acl_filter=None,
                     ipv6_dacl_name=None,
                     mac_sec_policy=None,
                     name=None,
                     neat=None,
                     profile_name=None,
                     reauth=None,
                     service_template=None,
                     track_movement=None,
                     vlan=None,
                     voice_domain_permission=None,
                     web_auth=None,
                     web_redirection=None,
                     headers=None,
                     payload=None,
                     active_validation=True,
                     **query_parameters):
        """Alias for `update_authorization_profile_by_id <#ciscoisesdk.
        api.v3_0_0.authorization_profile.
        AuthorizationProfile.update_authorization_profile_by_id>`_
        """
        return self.update_authorization_profile_by_id(
            id=id,
            access_type=access_type,
            acl=acl,
            advanced_attributes=advanced_attributes,
            agentless_posture=agentless_posture,
            airespace_acl=airespace_acl,
            airespace_ipv6_acl=airespace_ipv6_acl,
            asa_vpn=asa_vpn,
            authz_profile_type=authz_profile_type,
            auto_smart_port=auto_smart_port,
            avc_profile=avc_profile,
            dacl_name=dacl_name,
            description=description,
            easywired_session_candidate=easywired_session_candidate,
            interface_template=interface_template,
            ipv6_acl_filter=ipv6_acl_filter,
            ipv6_dacl_name=ipv6_dacl_name,
            mac_sec_policy=mac_sec_policy,
            name=name,
            neat=neat,
            profile_name=profile_name,
            reauth=reauth,
            service_template=service_template,
            track_movement=track_movement,
            vlan=vlan,
            voice_domain_permission=voice_domain_permission,
            web_auth=web_auth,
            web_redirection=web_redirection,
            payload=payload,
            active_validation=active_validation,
            headers=headers,
            **query_parameters
        )

    def delete_authorization_profile_by_id(self,
                                           id,
                                           headers=None,
                                           **query_parameters):
        """This API deletes an authorization profile.

        Args:
            id(basestring): id path parameter.
            headers(dict): Dictionary of HTTP Headers to send with the Request
                .
            **query_parameters: Additional query parameters (provides
                support for parameters that may be added in the future).

        Returns:

            RestResponse: REST response with following properties:

              - headers(MyDict): response headers.
              - response(MyDict): response body as a MyDict object. Access the object's properties by using the dot notation
                or the bracket notation.
              - content(bytes): representation of the request's response
              - text(str): representation of the request's response

        Raises:
            TypeError: If the parameter types are incorrect.
            MalformedRequest: If the request body created is invalid.
            ApiError: If the Identity Services Engine cloud returns an error.
        """
        check_type(headers, dict)

        if headers is not None:
            if 'Content-Type' in headers:
                check_type(headers.get('Content-Type'),
                           basestring, may_be_none=False)
            if 'Accept' in headers:
                check_type(headers.get('Accept'),
                           basestring, may_be_none=False)
            if 'ERS-Media-Type' in headers:
                check_type(headers.get('ERS-Media-Type'),
                           basestring)
            if 'X-CSRF-Token' in headers:
                check_type(headers.get('X-CSRF-Token'),
                           basestring)

        with_custom_headers = False
        _headers = self._session.headers or {}
        if headers:
            _headers.update(dict_of_str(headers))
            with_custom_headers = True
        check_type(id, basestring,
                   may_be_none=False)

        _params = {
        }
        _params.update(query_parameters)
        _params = dict_from_items_with_values(_params)

        path_params = {
            'id': id,
        }

        e_url = ('/ers/config/authorizationprofile/{id}')
        endpoint_full_url = apply_path_params(e_url, path_params)
        if with_custom_headers:
            _api_response = self._session.delete(endpoint_full_url, params=_params,
                                                 headers=_headers)
        else:
            _api_response = self._session.delete(endpoint_full_url, params=_params)

        return self._object_factory('bpm_c3913dfbda305f678ede16f782762ad3_v3_0_0', _api_response)

    def delete_by_id(self,
                     id,
                     headers=None,
                     **query_parameters):
        """Alias for `delete_authorization_profile_by_id <#ciscoisesdk.
        api.v3_0_0.authorization_profile.
        AuthorizationProfile.delete_authorization_profile_by_id>`_
        """
        return self.delete_authorization_profile_by_id(
            id=id,
            headers=headers,
            **query_parameters
        )

    def get_authorization_profiles(self,
                                   page=None,
                                   size=None,
                                   headers=None,
                                   **query_parameters):
        """This API allows the client to get all authorization profiles.

        Args:
            page(int): page query parameter. Page number.
            size(int): size query parameter. Number of objects
                returned per page.
            headers(dict): Dictionary of HTTP Headers to send with the Request
                .
            **query_parameters: Additional query parameters (provides
                support for parameters that may be added in the future).

        Returns:

            RestResponse: REST response with following properties:

              - headers(MyDict): response headers.
              - response(MyDict): response body as a MyDict object. Access the object's properties by using the dot notation
                or the bracket notation.
              - content(bytes): representation of the request's response
              - text(str): representation of the request's response

        Raises:
            TypeError: If the parameter types are incorrect.
            MalformedRequest: If the request body created is invalid.
            ApiError: If the Identity Services Engine cloud returns an error.
        """
        check_type(headers, dict)

        if headers is not None:
            if 'Content-Type' in headers:
                check_type(headers.get('Content-Type'),
                           basestring, may_be_none=False)
            if 'Accept' in headers:
                check_type(headers.get('Accept'),
                           basestring, may_be_none=False)
            if 'ERS-Media-Type' in headers:
                check_type(headers.get('ERS-Media-Type'),
                           basestring)
            if 'X-CSRF-Token' in headers:
                check_type(headers.get('X-CSRF-Token'),
                           basestring)

        with_custom_headers = False
        _headers = self._session.headers or {}
        if headers:
            _headers.update(dict_of_str(headers))
            with_custom_headers = True
        check_type(page, (int, basestring, list))
        check_type(size, (int, basestring, list))

        _params = {
            'page':
                page,
            'size':
                size,
        }
        _params.update(query_parameters)
        _params = dict_from_items_with_values(_params)

        path_params = {
        }

        e_url = ('/ers/config/authorizationprofile')
        endpoint_full_url = apply_path_params(e_url, path_params)
        if with_custom_headers:
            _api_response = self._session.get(endpoint_full_url, params=_params,
                                              headers=_headers)
        else:
            _api_response = self._session.get(endpoint_full_url, params=_params)

        return self._object_factory('bpm_e232c5666ab5ed783588f413c3bc644_v3_0_0', _api_response)

    def get_all(self,
                page=None,
                size=None,
                headers=None,
                **query_parameters):
        """Alias for `get_authorization_profiles <#ciscoisesdk.
        api.v3_0_0.authorization_profile.
        AuthorizationProfile.get_authorization_profiles>`_
        """
        return self.get_authorization_profiles(
            page=page,
            size=size,
            headers=headers,
            **query_parameters
        )

    def get_authorization_profiles_generator(self,
                                             page=None,
                                             size=None,
                                             headers=None,
                                             **query_parameters):
        """This API allows the client to get all authorization profiles.

        Args:
            page(int): page query parameter. Page number.
            size(int): size query parameter. Number of objects
                returned per page.
            headers(dict): Dictionary of HTTP Headers to send with the Request
                .
            **query_parameters: Additional query parameters (provides
                support for parameters that may be added in the future).

        Returns:
            Generator: A generator object containing the following object.

              + RestResponse: REST response with following properties:

                  - headers(MyDict): response headers.
                  - response(MyDict): response body as a MyDict object. Access the object's properties by using the dot notation
                    or the bracket notation.
                  - content(bytes): representation of the request's response
                  - text(str): representation of the request's response

        Raises:
            TypeError: If the parameter types are incorrect.
            MalformedRequest: If the request body created is invalid.
            ApiError: If the Identity Services Engine cloud returns an error.
        """

        yield from get_next_page(
            self.get_authorization_profiles, dict(
                page=page,
                size=size,
                headers=headers,
                **query_parameters
            ),
            access_next_list=["SearchResult", "nextPage", "href"],
            access_resource_list=["SearchResult", "resources"])

    def get_all_generator(self,
                          page=None,
                          size=None,
                          headers=None,
                          **query_parameters):
        """Alias for `get_authorization_profiles_generator <#ciscoisesdk.
        api.v3_0_0.authorization_profile.
        AuthorizationProfile.get_authorization_profiles_generator>`_
        """
        yield from get_next_page(
            self.get_authorization_profiles, dict(
                page=page,
                size=size,
                headers=headers,
                **query_parameters
            ),
            access_next_list=["SearchResult", "nextPage", "href"],
            access_resource_list=["SearchResult", "resources"])

    def create_authorization_profile(self,
                                     access_type=None,
                                     acl=None,
                                     advanced_attributes=None,
                                     agentless_posture=None,
                                     airespace_acl=None,
                                     airespace_ipv6_acl=None,
                                     asa_vpn=None,
                                     authz_profile_type=None,
                                     auto_smart_port=None,
                                     avc_profile=None,
                                     dacl_name=None,
                                     description=None,
                                     easywired_session_candidate=None,
                                     id=None,
                                     interface_template=None,
                                     ipv6_acl_filter=None,
                                     ipv6_dacl_name=None,
                                     mac_sec_policy=None,
                                     name=None,
                                     neat=None,
                                     profile_name=None,
                                     reauth=None,
                                     service_template=None,
                                     track_movement=None,
                                     vlan=None,
                                     voice_domain_permission=None,
                                     web_auth=None,
                                     web_redirection=None,
                                     headers=None,
                                     payload=None,
                                     active_validation=True,
                                     **query_parameters):
        """This API creates an authorization profile.

        Args:
            access_type(string): Allowed Values: ACCESS_ACCEPT,
                ACCESS_REJECT, property of the request
                body.
            acl(string): acl, property of the request body.
            advanced_attributes(list): advancedAttributes, property
                of the request body (list of objects).
            agentless_posture(boolean): agentlessPosture, property
                of the request body.
            airespace_acl(string): airespaceACL, property of the
                request body.
            airespace_ipv6_acl(string): airespaceIPv6ACL, property
                of the request body.
            asa_vpn(string): asaVpn, property of the request body.
            authz_profile_type(string): Allowed Values: SWITCH,
                TRUSTSEC, TACACS SWITCH is used for
                Standard Authorization Profiles,
                property of the request body.
            auto_smart_port(string): autoSmartPort, property of the
                request body.
            avc_profile(string): avcProfile, property of the request
                body.
            dacl_name(string): daclName, property of the request
                body.
            description(string): description, property of the
                request body.
            easywired_session_candidate(boolean):
                easywiredSessionCandidate, property of
                the request body.
            id(string): Resource UUID value, property of the request
                body.
            interface_template(string): interfaceTemplate, property
                of the request body.
            ipv6_acl_filter(string): ipv6ACLFilter, property of the
                request body.
            ipv6_dacl_name(string): ipv6DaclName, property of the
                request body.
            mac_sec_policy(string): Allowed Values: MUST_SECURE,
                MUST_NOT_SECURE, SHOULD_SECURE, property
                of the request body.
            name(string): Resource Name, property of the request
                body.
            neat(boolean): neat, property of the request body.
            profile_name(string): profileName, property of the
                request body.
            reauth(object): reauth, property of the request body.
            service_template(boolean): serviceTemplate, property of
                the request body.
            track_movement(boolean): trackMovement, property of the
                request body.
            vlan(object): vlan, property of the request body.
            voice_domain_permission(boolean): voiceDomainPermission,
                property of the request body.
            web_auth(boolean): webAuth, property of the request
                body.
            web_redirection(object): webRedirection, property of the
                request body.
            headers(dict): Dictionary of HTTP Headers to send with the Request
                .
            payload(dict): A JSON serializable Python object to send in the
                body of the Request.
            active_validation(bool): Enable/Disable payload validation.
                Defaults to True.
            **query_parameters: Additional query parameters (provides
                support for parameters that may be added in the future).

        Returns:

            RestResponse: REST response with following properties:

              - headers(MyDict): response headers.
              - response(MyDict): response body as a MyDict object. Access the object's properties by using the dot notation
                or the bracket notation.
              - content(bytes): representation of the request's response
              - text(str): representation of the request's response

        Raises:
            TypeError: If the parameter types are incorrect.
            MalformedRequest: If the request body created is invalid.
            ApiError: If the Identity Services Engine cloud returns an error.
        """
        check_type(headers, dict)

        if headers is not None:
            if 'Content-Type' in headers:
                check_type(headers.get('Content-Type'),
                           basestring, may_be_none=False)
            if 'Accept' in headers:
                check_type(headers.get('Accept'),
                           basestring, may_be_none=False)
            if 'ERS-Media-Type' in headers:
                check_type(headers.get('ERS-Media-Type'),
                           basestring)
            if 'X-CSRF-Token' in headers:
                check_type(headers.get('X-CSRF-Token'),
                           basestring)

        with_custom_headers = False
        _headers = self._session.headers or {}
        if headers:
            _headers.update(dict_of_str(headers))
            with_custom_headers = True
        is_xml_payload = 'application/xml' in _headers.get('Content-Type', [])
        if active_validation and is_xml_payload:
            check_type(payload, basestring)
        if active_validation and not is_xml_payload:
            check_type(payload, dict)

        _params = {
        }
        _params.update(query_parameters)
        _params = dict_from_items_with_values(_params)

        path_params = {
        }
        if is_xml_payload:
            _payload = payload
        else:
            _tmp_payload = {
                'id':
                    id,
                'name':
                    name,
                'description':
                    description,
                'advancedAttributes':
                    advanced_attributes,
                'accessType':
                    access_type,
                'authzProfileType':
                    authz_profile_type,
                'vlan':
                    vlan,
                'reauth':
                    reauth,
                'airespaceACL':
                    airespace_acl,
                'airespaceIPv6ACL':
                    airespace_ipv6_acl,
                'webRedirection':
                    web_redirection,
                'acl':
                    acl,
                'trackMovement':
                    track_movement,
                'agentlessPosture':
                    agentless_posture,
                'serviceTemplate':
                    service_template,
                'easywiredSessionCandidate':
                    easywired_session_candidate,
                'daclName':
                    dacl_name,
                'voiceDomainPermission':
                    voice_domain_permission,
                'neat':
                    neat,
                'webAuth':
                    web_auth,
                'autoSmartPort':
                    auto_smart_port,
                'interfaceTemplate':
                    interface_template,
                'ipv6ACLFilter':
                    ipv6_acl_filter,
                'avcProfile':
                    avc_profile,
                'macSecPolicy':
                    mac_sec_policy,
                'asaVpn':
                    asa_vpn,
                'profileName':
                    profile_name,
                'ipv6DaclName':
                    ipv6_dacl_name,
            }
            _payload = {
                'AuthorizationProfile': dict_from_items_with_values(_tmp_payload)
            }
            _payload.update(payload or {})
            _payload = dict_from_items_with_values(_payload)
        if active_validation and not is_xml_payload:
            self._request_validator('jsd_c43118f80d4556a8ec759a8c41e2097_v3_0_0')\
                .validate(_payload)

        e_url = ('/ers/config/authorizationprofile')
        endpoint_full_url = apply_path_params(e_url, path_params)

        request_params = {'data': _payload} if is_xml_payload else {'json': _payload}
        if with_custom_headers:
            _api_response = self._session.post(endpoint_full_url, params=_params,
                                               headers=_headers,
                                               **request_params)
        else:
            _api_response = self._session.post(endpoint_full_url, params=_params,
                                               **request_params)

        return self._object_factory('bpm_c43118f80d4556a8ec759a8c41e2097_v3_0_0', _api_response)

    def create(self,
               access_type=None,
               acl=None,
               advanced_attributes=None,
               agentless_posture=None,
               airespace_acl=None,
               airespace_ipv6_acl=None,
               asa_vpn=None,
               authz_profile_type=None,
               auto_smart_port=None,
               avc_profile=None,
               dacl_name=None,
               description=None,
               easywired_session_candidate=None,
               id=None,
               interface_template=None,
               ipv6_acl_filter=None,
               ipv6_dacl_name=None,
               mac_sec_policy=None,
               name=None,
               neat=None,
               profile_name=None,
               reauth=None,
               service_template=None,
               track_movement=None,
               vlan=None,
               voice_domain_permission=None,
               web_auth=None,
               web_redirection=None,
               headers=None,
               payload=None,
               active_validation=True,
               **query_parameters):
        """Alias for `create_authorization_profile <#ciscoisesdk.
        api.v3_0_0.authorization_profile.
        AuthorizationProfile.create_authorization_profile>`_
        """
        return self.create_authorization_profile(
            access_type=access_type,
            acl=acl,
            advanced_attributes=advanced_attributes,
            agentless_posture=agentless_posture,
            airespace_acl=airespace_acl,
            airespace_ipv6_acl=airespace_ipv6_acl,
            asa_vpn=asa_vpn,
            authz_profile_type=authz_profile_type,
            auto_smart_port=auto_smart_port,
            avc_profile=avc_profile,
            dacl_name=dacl_name,
            description=description,
            easywired_session_candidate=easywired_session_candidate,
            id=id,
            interface_template=interface_template,
            ipv6_acl_filter=ipv6_acl_filter,
            ipv6_dacl_name=ipv6_dacl_name,
            mac_sec_policy=mac_sec_policy,
            name=name,
            neat=neat,
            profile_name=profile_name,
            reauth=reauth,
            service_template=service_template,
            track_movement=track_movement,
            vlan=vlan,
            voice_domain_permission=voice_domain_permission,
            web_auth=web_auth,
            web_redirection=web_redirection,
            payload=payload,
            active_validation=active_validation,
            headers=headers,
            **query_parameters
        )

    def get_version(self,
                    headers=None,
                    **query_parameters):
        """This API helps to retrieve the version information related to
        the authorization profile.

        Args:
            headers(dict): Dictionary of HTTP Headers to send with the Request
                .
            **query_parameters: Additional query parameters (provides
                support for parameters that may be added in the future).

        Returns:

            RestResponse: REST response with following properties:

              - headers(MyDict): response headers.
              - response(MyDict): response body as a MyDict object. Access the object's properties by using the dot notation
                or the bracket notation.
              - content(bytes): representation of the request's response
              - text(str): representation of the request's response

        Raises:
            TypeError: If the parameter types are incorrect.
            MalformedRequest: If the request body created is invalid.
            ApiError: If the Identity Services Engine cloud returns an error.
        """
        check_type(headers, dict)

        if headers is not None:
            if 'Content-Type' in headers:
                check_type(headers.get('Content-Type'),
                           basestring, may_be_none=False)
            if 'Accept' in headers:
                check_type(headers.get('Accept'),
                           basestring, may_be_none=False)

        with_custom_headers = False
        _headers = self._session.headers or {}
        if headers:
            _headers.update(dict_of_str(headers))
            with_custom_headers = True

        _params = {
        }
        _params.update(query_parameters)
        _params = dict_from_items_with_values(_params)

        path_params = {
        }

        e_url = ('/ers/config/authorizationprofile/versioninfo')
        endpoint_full_url = apply_path_params(e_url, path_params)
        if with_custom_headers:
            _api_response = self._session.get(endpoint_full_url, params=_params,
                                              headers=_headers)
        else:
            _api_response = self._session.get(endpoint_full_url, params=_params)

        return self._object_factory('bpm_bee8aa3a03a57a3a5eb1418fe1250b6_v3_0_0', _api_response)



# -*- coding: utf-8 -*-
"""Cisco Identity Services Engine Network Access - Authorization Exception Rules API wrapper.

Copyright (c) 2021 Cisco and/or its affiliates.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


from __future__ import (
    absolute_import,
    division,
    print_function,
    unicode_literals,
)

from builtins import *

from past.builtins import basestring

from ...restsession import RestSession
from ...utils import (
    check_type,
    dict_from_items_with_values,
    apply_path_params,
    dict_of_str,
)
from ...pagination import get_next_page


class NetworkAccessAuthorizationExceptionRules(object):
    """Identity Services Engine Network Access - Authorization Exception Rules API (version: 3.1.0).

    Wraps the Identity Services Engine Network Access - Authorization Exception Rules
    API and exposes the API as native Python
    methods that return native Python objects.



    """

    def __init__(self, session, object_factory, request_validator):
        """Initialize a new NetworkAccessAuthorizationExceptionRules
        object with the provided RestSession.

        Args:
            session(RestSession): The RESTful session object to be used for
                API calls to the Identity Services Engine service.

        Raises:
            TypeError: If the parameter types are incorrect.

        """
        check_type(session, RestSession)

        super(NetworkAccessAuthorizationExceptionRules, self).__init__()

        self._session = session
        self._object_factory = object_factory
        self._request_validator = request_validator

    def get_network_access_local_exception_rules(self,
                                                 policy_id,
                                                 headers=None,
                                                 **query_parameters):
        """Network Access Get local exception rules.

        Args:
            policy_id(basestring): policyId path parameter. Policy
                id.
            headers(dict): Dictionary of HTTP Headers to send with the Request
                .
            **query_parameters: Additional query parameters (provides
                support for parameters that may be added in the future).

        Returns:

            RestResponse: REST response with following properties:

              - headers(MyDict): response headers.
              - response(MyDict): response body as a MyDict object. Access the object's properties by using the dot notation
                or the bracket notation.
              - content(bytes): representation of the request's response
              - text(str): representation of the request's response

        Raises:
            TypeError: If the parameter types are incorrect.
            MalformedRequest: If the request body created is invalid.
            ApiError: If the Identity Services Engine cloud returns an error.
        """
        check_type(headers, dict)

        if headers is not None:
            if 'X-Request-ID' in headers:
                check_type(headers.get('X-Request-ID'),
                           basestring)

        with_custom_headers = False
        _headers = self._session.headers or {}
        if headers:
            _headers.update(dict_of_str(headers))
            with_custom_headers = True
        check_type(policy_id, basestring,
                   may_be_none=False)

        _params = {
        }
        _params.update(query_parameters)
        _params = dict_from_items_with_values(_params)

        path_params = {
            'policyId': policy_id,
        }

        e_url = ('/api/v1/policy/network-access/policy-'
                 + 'set/{policyId}/exception')
        endpoint_full_url = apply_path_params(e_url, path_params)
        if with_custom_headers:
            _api_response = self._session.get(endpoint_full_url, params=_params,
                                              headers=_headers)
        else:
            _api_response = self._session.get(endpoint_full_url, params=_params)

        return self._object_factory('bpm_e23ac4c658f5b75f19d13d6f7189_v3_1_0', _api_response)

    def get_all(self,
                policy_id,
                headers=None,
                **query_parameters):
        """Alias for `get_network_access_local_exception_rules <#ciscoisesdk.
        api.v3_1_0.network_access_authorization_exception_rules.
        NetworkAccessAuthorizationExceptionRules.get_network_access_local_exception_rules>`_
        """
        return self.get_network_access_local_exception_rules(
            policy_id=policy_id,
            headers=headers,
            **query_parameters
        )

    def create_network_access_local_exception_rule(self,
                                                   policy_id,
                                                   link=None,
                                                   profile=None,
                                                   rule=None,
                                                   security_group=None,
                                                   headers=None,
                                                   payload=None,
                                                   active_validation=True,
                                                   **query_parameters):
        """Network Access Create local authorization exception rule:
        Rule must include name and condition.     Condition has
        hierarchical structure which define a set of conditions
        for which authoriztion policy rule could be match.
        Condition can be either reference to a stored Library
        condition, using model  ConditionReference    or
        dynamically built conditions which are not stored in the
        conditions Library, using models  ConditionAttributes,
        ConditionAndBlock, ConditionOrBlock .    .

        Args:
            link(object): link, property of the request body.
            profile(list): The authorization profile/s, property of
                the request body (list of strings).
            rule(object): Common attributes in rule
                authentication/authorization, property
                of the request body.
            security_group(string): Security group used in
                authorization policies, property of the
                request body.
            policy_id(basestring): policyId path parameter. Policy
                id.
            headers(dict): Dictionary of HTTP Headers to send with the Request
                .
            payload(dict): A JSON serializable Python object to send in the
                body of the Request.
            active_validation(bool): Enable/Disable payload validation.
                Defaults to True.
            **query_parameters: Additional query parameters (provides
                support for parameters that may be added in the future).

        Returns:

            RestResponse: REST response with following properties:

              - headers(MyDict): response headers.
              - response(MyDict): response body as a MyDict object. Access the object's properties by using the dot notation
                or the bracket notation.
              - content(bytes): representation of the request's response
              - text(str): representation of the request's response

        Raises:
            TypeError: If the parameter types are incorrect.
            MalformedRequest: If the request body created is invalid.
            ApiError: If the Identity Services Engine cloud returns an error.
        """
        check_type(headers, dict)

        if headers is not None:
            if 'X-Request-ID' in headers:
                check_type(headers.get('X-Request-ID'),
                           basestring)

        with_custom_headers = False
        _headers = self._session.headers or {}
        if headers:
            _headers.update(dict_of_str(headers))
            with_custom_headers = True
        is_xml_payload = 'application/xml' in _headers.get('Content-Type', [])
        if active_validation and is_xml_payload:
            check_type(payload, basestring)
        if active_validation and not is_xml_payload:
            check_type(payload, dict)
        check_type(policy_id, basestring,
                   may_be_none=False)

        _params = {
        }
        _params.update(query_parameters)
        _params = dict_from_items_with_values(_params)

        path_params = {
            'policyId': policy_id,
        }
        if is_xml_payload:
            _payload = payload
        else:
            _payload = {
                'link':
                    link,
                'profile':
                    profile,
                'rule':
                    rule,
                'securityGroup':
                    security_group,
            }
            _payload.update(payload or {})
            _payload = dict_from_items_with_values(_payload)
        if active_validation and not is_xml_payload:
            self._request_validator('jsd_c475afd2a5e57e4bd0952f2c5349c6c_v3_1_0')\
                .validate(_payload)

        e_url = ('/api/v1/policy/network-access/policy-'
                 + 'set/{policyId}/exception')
        endpoint_full_url = apply_path_params(e_url, path_params)

        request_params = {'data': _payload} if is_xml_payload else {'json': _payload}
        if with_custom_headers:
            _api_response = self._session.post(endpoint_full_url, params=_params,
                                               headers=_headers,
                                               **request_params)
        else:
            _api_response = self._session.post(endpoint_full_url, params=_params,
                                               **request_params)

        return self._object_factory('bpm_c475afd2a5e57e4bd0952f2c5349c6c_v3_1_0', _api_response)

    def create(self,
               policy_id,
               link=None,
               profile=None,
               rule=None,
               security_group=None,
               headers=None,
               payload=None,
               active_validation=True,
               **query_parameters):
        """Alias for `create_network_access_local_exception_rule <#ciscoisesdk.
        api.v3_1_0.network_access_authorization_exception_rules.
        NetworkAccessAuthorizationExceptionRules.create_network_access_local_exception_rule>`_
        """
        return self.create_network_access_local_exception_rule(
            policy_id=policy_id,
            link=link,
            profile=profile,
            rule=rule,
            security_group=security_group,
            payload=payload,
            active_validation=active_validation,
            headers=headers,
            **query_parameters
        )

    def reset_hit_counts_network_access_local_exceptions(self,
                                                         policy_id,
                                                         headers=None,
                                                         **query_parameters):
        """Network Access Reset HitCount for local exceptions.

        Args:
            policy_id(basestring): policyId path parameter. Policy
                id.
            headers(dict): Dictionary of HTTP Headers to send with the Request
                .
            **query_parameters: Additional query parameters (provides
                support for parameters that may be added in the future).

        Returns:

            RestResponse: REST response with following properties:

              - headers(MyDict): response headers.
              - response(MyDict): response body as a MyDict object. Access the object's properties by using the dot notation
                or the bracket notation.
              - content(bytes): representation of the request's response
              - text(str): representation of the request's response

        Raises:
            TypeError: If the parameter types are incorrect.
            MalformedRequest: If the request body created is invalid.
            ApiError: If the Identity Services Engine cloud returns an error.
        """
        check_type(headers, dict)

        if headers is not None:
            if 'X-Request-ID' in headers:
                check_type(headers.get('X-Request-ID'),
                           basestring)

        with_custom_headers = False
        _headers = self._session.headers or {}
        if headers:
            _headers.update(dict_of_str(headers))
            with_custom_headers = True
        check_type(policy_id, basestring,
                   may_be_none=False)

        _params = {
        }
        _params.update(query_parameters)
        _params = dict_from_items_with_values(_params)

        path_params = {
            'policyId': policy_id,
        }

        e_url = ('/api/v1/policy/network-access/policy-'
                 + 'set/{policyId}/exception/reset-hitcount')
        endpoint_full_url = apply_path_params(e_url, path_params)

        if with_custom_headers:
            _api_response = self._session.post(endpoint_full_url, params=_params,
                                               headers=_headers)
        else:
            _api_response = self._session.post(endpoint_full_url, params=_params)

        return self._object_factory('bpm_fc04e49e2a959cd8c498858e46f72f2_v3_1_0', _api_response)

    def reset_hit_counts_by_id(self,
                               policy_id,
                               headers=None,
                               **query_parameters):
        """Alias for `reset_hit_counts_network_access_local_exceptions <#ciscoisesdk.
        api.v3_1_0.network_access_authorization_exception_rules.
        NetworkAccessAuthorizationExceptionRules.reset_hit_counts_network_access_local_exceptions>`_
        """
        return self.reset_hit_counts_network_access_local_exceptions(
            policy_id=policy_id,
            headers=headers,
            **query_parameters
        )

    def get_network_access_local_exception_rule_by_id(self,
                                                      id,
                                                      policy_id,
                                                      headers=None,
                                                      **query_parameters):
        """Network Access Get local exception rule attributes.

        Args:
            policy_id(basestring): policyId path parameter. Policy
                id.
            id(basestring): id path parameter. Rule id.
            headers(dict): Dictionary of HTTP Headers to send with the Request
                .
            **query_parameters: Additional query parameters (provides
                support for parameters that may be added in the future).

        Returns:

            RestResponse: REST response with following properties:

              - headers(MyDict): response headers.
              - response(MyDict): response body as a MyDict object. Access the object's properties by using the dot notation
                or the bracket notation.
              - content(bytes): representation of the request's response
              - text(str): representation of the request's response

        Raises:
            TypeError: If the parameter types are incorrect.
            MalformedRequest: If the request body created is invalid.
            ApiError: If the Identity Services Engine cloud returns an error.
        """
        check_type(headers, dict)

        if headers is not None:
            if 'X-Request-ID' in headers:
                check_type(headers.get('X-Request-ID'),
                           basestring)

        with_custom_headers = False
        _headers = self._session.headers or {}
        if headers:
            _headers.update(dict_of_str(headers))
            with_custom_headers = True
        check_type(policy_id, basestring,
                   may_be_none=False)
        check_type(id, basestring,
                   may_be_none=False)

        _params = {
        }
        _params.update(query_parameters)
        _params = dict_from_items_with_values(_params)

        path_params = {
            'policyId': policy_id,
            'id': id,
        }

        e_url = ('/api/v1/policy/network-access/policy-'
                 + 'set/{policyId}/exception/{id}')
        endpoint_full_url = apply_path_params(e_url, path_params)
        if with_custom_headers:
            _api_response = self._session.get(endpoint_full_url, params=_params,
                                              headers=_headers)
        else:
            _api_response = self._session.get(endpoint_full_url, params=_params)

        return self._object_factory('bpm_b3fe0f3ea8a5368aea79a847288993e_v3_1_0', _api_response)

    def get_by_id(self,
                  id,
                  policy_id,
                  headers=None,
                  **query_parameters):
        """Alias for `get_network_access_local_exception_rule_by_id <#ciscoisesdk.
        api.v3_1_0.network_access_authorization_exception_rules.
        NetworkAccessAuthorizationExceptionRules.get_network_access_local_exception_rule_by_id>`_
        """
        return self.get_network_access_local_exception_rule_by_id(
            id=id,
            policy_id=policy_id,
            headers=headers,
            **query_parameters
        )

    def update_network_access_local_exception_rule_by_id(self,
                                                         id,
                                                         policy_id,
                                                         link=None,
                                                         profile=None,
                                                         rule=None,
                                                         security_group=None,
                                                         headers=None,
                                                         payload=None,
                                                         active_validation=True,
                                                         **query_parameters):
        """Network Access Update local exception rule.

        Args:
            link(object): link, property of the request body.
            profile(list): The authorization profile/s, property of
                the request body (list of strings).
            rule(object): Common attributes in rule
                authentication/authorization, property
                of the request body.
            security_group(string): Security group used in
                authorization policies, property of the
                request body.
            policy_id(basestring): policyId path parameter. Policy
                id.
            id(basestring): id path parameter. Rule id.
            headers(dict): Dictionary of HTTP Headers to send with the Request
                .
            payload(dict): A JSON serializable Python object to send in the
                body of the Request.
            active_validation(bool): Enable/Disable payload validation.
                Defaults to True.
            **query_parameters: Additional query parameters (provides
                support for parameters that may be added in the future).

        Returns:

            RestResponse: REST response with following properties:

              - headers(MyDict): response headers.
              - response(MyDict): response body as a MyDict object. Access the object's properties by using the dot notation
                or the bracket notation.
              - content(bytes): representation of the request's response
              - text(str): representation of the request's response

        Raises:
            TypeError: If the parameter types are incorrect.
            MalformedRequest: If the request body created is invalid.
            ApiError: If the Identity Services Engine cloud returns an error.
        """
        check_type(headers, dict)

        if headers is not None:
            if 'X-Request-ID' in headers:
                check_type(headers.get('X-Request-ID'),
                           basestring)

        with_custom_headers = False
        _headers = self._session.headers or {}
        if headers:
            _headers.update(dict_of_str(headers))
            with_custom_headers = True
        is_xml_payload = 'application/xml' in _headers.get('Content-Type', [])
        if active_validation and is_xml_payload:
            check_type(payload, basestring)
        if active_validation and not is_xml_payload:
            check_type(payload, dict)
        check_type(policy_id, basestring,
                   may_be_none=False)
        check_type(id, basestring,
                   may_be_none=False)

        _params = {
        }
        _params.update(query_parameters)
        _params = dict_from_items_with_values(_params)

        path_params = {
            'policyId': policy_id,
            'id': id,
        }
        if is_xml_payload:
            _payload = payload
        else:
            _payload = {
                'link':
                    link,
                'profile':
                    profile,
                'rule':
                    rule,
                'securityGroup':
                    security_group,
            }
            _payload.update(payload or {})
            _payload = dict_from_items_with_values(_payload)
        if active_validation and not is_xml_payload:
            self._request_validator('jsd_a22b2304dcc855abb2a298de6ecddb65_v3_1_0')\
                .validate(_payload)

        e_url = ('/api/v1/policy/network-access/policy-'
                 + 'set/{policyId}/exception/{id}')
        endpoint_full_url = apply_path_params(e_url, path_params)

        request_params = {'data': _payload} if is_xml_payload else {'json': _payload}
        if with_custom_headers:
            _api_response = self._session.put(endpoint_full_url, params=_params,
                                              headers=_headers,
                                              **request_params)

        else:
            _api_response = self._session.put(endpoint_full_url, params=_params,
                                              **request_params)

        return self._object_factory('bpm_a22b2304dcc855abb2a298de6ecddb65_v3_1_0', _api_response)

    def update_by_id(self,
                     id,
                     policy_id,
                     link=None,
                     profile=None,
                     rule=None,
                     security_group=None,
                     headers=None,
                     payload=None,
                     active_validation=True,
                     **query_parameters):
        """Alias for `update_network_access_local_exception_rule_by_id <#ciscoisesdk.
        api.v3_1_0.network_access_authorization_exception_rules.
        NetworkAccessAuthorizationExceptionRules.update_network_access_local_exception_rule_by_id>`_
        """
        return self.update_network_access_local_exception_rule_by_id(
            id=id,
            policy_id=policy_id,
            link=link,
            profile=profile,
            rule=rule,
            security_group=security_group,
            payload=payload,
            active_validation=active_validation,
            headers=headers,
            **query_parameters
        )

    def delete_network_access_local_exception_rule_by_id(self,
                                                         id,
                                                         policy_id,
                                                         headers=None,
                                                         **query_parameters):
        """Network Access Delete local exception rule.

        Args:
            policy_id(basestring): policyId path parameter. Policy
                id.
            id(basestring): id path parameter. Rule id.
            headers(dict): Dictionary of HTTP Headers to send with the Request
                .
            **query_parameters: Additional query parameters (provides
                support for parameters that may be added in the future).

        Returns:

            RestResponse: REST response with following properties:

              - headers(MyDict): response headers.
              - response(MyDict): response body as a MyDict object. Access the object's properties by using the dot notation
                or the bracket notation.
              - content(bytes): representation of the request's response
              - text(str): representation of the request's response

        Raises:
            TypeError: If the parameter types are incorrect.
            MalformedRequest: If the request body created is invalid.
            ApiError: If the Identity Services Engine cloud returns an error.
        """
        check_type(headers, dict)

        if headers is not None:
            if 'X-Request-ID' in headers:
                check_type(headers.get('X-Request-ID'),
                           basestring)

        with_custom_headers = False
        _headers = self._session.headers or {}
        if headers:
            _headers.update(dict_of_str(headers))
            with_custom_headers = True
        check_type(policy_id, basestring,
                   may_be_none=False)
        check_type(id, basestring,
                   may_be_none=False)

        _params = {
        }
        _params.update(query_parameters)
        _params = dict_from_items_with_values(_params)

        path_params = {
            'policyId': policy_id,
            'id': id,
        }

        e_url = ('/api/v1/policy/network-access/policy-'
                 + 'set/{policyId}/exception/{id}')
        endpoint_full_url = apply_path_params(e_url, path_params)
        if with_custom_headers:
            _api_response = self._session.delete(endpoint_full_url, params=_params,
                                                 headers=_headers)
        else:
            _api_response = self._session.delete(endpoint_full_url, params=_params)

        return self._object_factory('bpm_c0ec3a56f65447ba863ae0cac5ef6a_v3_1_0', _api_response)

    def delete_by_id(self,
                     id,
                     policy_id,
                     headers=None,
                     **query_parameters):
        """Alias for `delete_network_access_local_exception_rule_by_id <#ciscoisesdk.
        api.v3_1_0.network_access_authorization_exception_rules.
        NetworkAccessAuthorizationExceptionRules.delete_network_access_local_exception_rule_by_id>`_
        """
        return self.delete_network_access_local_exception_rule_by_id(
            id=id,
            policy_id=policy_id,
            headers=headers,
            **query_parameters
        )



# -*- coding: utf-8 -*-
"""Cisco Identity Services Engine Node Services API wrapper.

Copyright (c) 2021 Cisco and/or its affiliates.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


from __future__ import (
    absolute_import,
    division,
    print_function,
    unicode_literals,
)

from builtins import *

from past.builtins import basestring

from ...restsession import RestSession
from ...utils import (
    check_type,
    dict_from_items_with_values,
    apply_path_params,
    dict_of_str,
)
from ...pagination import get_next_page


class NodeServices(object):
    """Identity Services Engine Node Services API (version: 3.1.1).

    Wraps the Identity Services Engine Node Services
    API and exposes the API as native Python
    methods that return native Python objects.



    """

    def __init__(self, session, object_factory, request_validator):
        """Initialize a new NodeServices
        object with the provided RestSession.

        Args:
            session(RestSession): The RESTful session object to be used for
                API calls to the Identity Services Engine service.

        Raises:
            TypeError: If the parameter types are incorrect.

        """
        check_type(session, RestSession)

        super(NodeServices, self).__init__()

        self._session = session
        self._object_factory = object_factory
        self._request_validator = request_validator

    def get_interfaces(self,
                       hostname,
                       headers=None,
                       **query_parameters):
        """This API retrieves the list of interfaces on a node in a
        cluster. .

        Args:
            hostname(basestring): hostname path parameter. Hostname
                of the node.
            headers(dict): Dictionary of HTTP Headers to send with the Request
                .
            **query_parameters: Additional query parameters (provides
                support for parameters that may be added in the future).

        Returns:

            RestResponse: REST response with following properties:

              - headers(MyDict): response headers.
              - response(MyDict): response body as a MyDict object. Access the object's properties by using the dot notation
                or the bracket notation.
              - content(bytes): representation of the request's response
              - text(str): representation of the request's response

        Raises:
            TypeError: If the parameter types are incorrect.
            MalformedRequest: If the request body created is invalid.
            ApiError: If the Identity Services Engine cloud returns an error.
        """
        check_type(headers, dict)

        if headers is not None:
            pass

        with_custom_headers = False
        _headers = self._session.headers or {}
        if headers:
            _headers.update(dict_of_str(headers))
            with_custom_headers = True
        check_type(hostname, basestring,
                   may_be_none=False)

        _params = {
        }
        _params.update(query_parameters)
        _params = dict_from_items_with_values(_params)

        path_params = {
            'hostname': hostname,
        }

        e_url = ('/api/v1/node/{hostname}/interface')
        endpoint_full_url = apply_path_params(e_url, path_params)
        if with_custom_headers:
            _api_response = self._session.get(endpoint_full_url, params=_params,
                                              headers=_headers)
        else:
            _api_response = self._session.get(endpoint_full_url, params=_params)

        return self._object_factory('bpm_f6f429e124ea58ba85f0b34296d61300_v3_1_1', _api_response)

    def get_sxp_interface(self,
                          hostname,
                          headers=None,
                          **query_parameters):
        """This API retrieves the SXP interface. .

        Args:
            hostname(basestring): hostname path parameter. Hostname
                of the node.
            headers(dict): Dictionary of HTTP Headers to send with the Request
                .
            **query_parameters: Additional query parameters (provides
                support for parameters that may be added in the future).

        Returns:

            RestResponse: REST response with following properties:

              - headers(MyDict): response headers.
              - response(MyDict): response body as a MyDict object. Access the object's properties by using the dot notation
                or the bracket notation.
              - content(bytes): representation of the request's response
              - text(str): representation of the request's response

        Raises:
            TypeError: If the parameter types are incorrect.
            MalformedRequest: If the request body created is invalid.
            ApiError: If the Identity Services Engine cloud returns an error.
        """
        check_type(headers, dict)

        if headers is not None:
            pass

        with_custom_headers = False
        _headers = self._session.headers or {}
        if headers:
            _headers.update(dict_of_str(headers))
            with_custom_headers = True
        check_type(hostname, basestring,
                   may_be_none=False)

        _params = {
        }
        _params.update(query_parameters)
        _params = dict_from_items_with_values(_params)

        path_params = {
            'hostname': hostname,
        }

        e_url = ('/api/v1/node/{hostname}/sxp-interface')
        endpoint_full_url = apply_path_params(e_url, path_params)
        if with_custom_headers:
            _api_response = self._session.get(endpoint_full_url, params=_params,
                                              headers=_headers)
        else:
            _api_response = self._session.get(endpoint_full_url, params=_params)

        return self._object_factory('bpm_ba4b550caf3845b4cbe1074d_v3_1_1', _api_response)

    def set_sxp_interface(self,
                          hostname,
                          interface=None,
                          headers=None,
                          payload=None,
                          active_validation=True,
                          **query_parameters):
        """This API configures the SXP interface. .

        Args:
            interface(string): interface, property of the request
                body.
            hostname(basestring): hostname path parameter. Hostname
                of the node.
            headers(dict): Dictionary of HTTP Headers to send with the Request
                .
            payload(dict): A JSON serializable Python object to send in the
                body of the Request.
            active_validation(bool): Enable/Disable payload validation.
                Defaults to True.
            **query_parameters: Additional query parameters (provides
                support for parameters that may be added in the future).

        Returns:

            RestResponse: REST response with following properties:

              - headers(MyDict): response headers.
              - response(MyDict): response body as a MyDict object. Access the object's properties by using the dot notation
                or the bracket notation.
              - content(bytes): representation of the request's response
              - text(str): representation of the request's response

        Raises:
            TypeError: If the parameter types are incorrect.
            MalformedRequest: If the request body created is invalid.
            ApiError: If the Identity Services Engine cloud returns an error.
        """
        check_type(headers, dict)

        if headers is not None:
            pass

        with_custom_headers = False
        _headers = self._session.headers or {}
        if headers:
            _headers.update(dict_of_str(headers))
            with_custom_headers = True
        is_xml_payload = 'application/xml' in _headers.get('Content-Type', [])
        if active_validation and is_xml_payload:
            check_type(payload, basestring)
        if active_validation and not is_xml_payload:
            check_type(payload, dict)
        check_type(hostname, basestring,
                   may_be_none=False)

        _params = {
        }
        _params.update(query_parameters)
        _params = dict_from_items_with_values(_params)

        path_params = {
            'hostname': hostname,
        }
        if is_xml_payload:
            _payload = payload
        else:
            _payload = {
                'interface':
                    interface,
            }
            _payload.update(payload or {})
            _payload = dict_from_items_with_values(_payload)
        if active_validation and not is_xml_payload:
            self._request_validator('jsd_c6d188a13915253869849c4b0be7759_v3_1_1')\
                .validate(_payload)

        e_url = ('/api/v1/node/{hostname}/sxp-interface')
        endpoint_full_url = apply_path_params(e_url, path_params)

        request_params = {'data': _payload} if is_xml_payload else {'json': _payload}
        if with_custom_headers:
            _api_response = self._session.put(endpoint_full_url, params=_params,
                                              headers=_headers,
                                              **request_params)

        else:
            _api_response = self._session.put(endpoint_full_url, params=_params,
                                              **request_params)

        return self._object_factory('bpm_c6d188a13915253869849c4b0be7759_v3_1_1', _api_response)

    def get_profiler_probe_config(self,
                                  hostname,
                                  headers=None,
                                  **query_parameters):
        """This API retrieves the profiler probe configuration of a PSN. .

        Args:
            hostname(basestring): hostname path parameter. Hostname
                of the node.
            headers(dict): Dictionary of HTTP Headers to send with the Request
                .
            **query_parameters: Additional query parameters (provides
                support for parameters that may be added in the future).

        Returns:

            RestResponse: REST response with following properties:

              - headers(MyDict): response headers.
              - response(MyDict): response body as a MyDict object. Access the object's properties by using the dot notation
                or the bracket notation.
              - content(bytes): representation of the request's response
              - text(str): representation of the request's response

        Raises:
            TypeError: If the parameter types are incorrect.
            MalformedRequest: If the request body created is invalid.
            ApiError: If the Identity Services Engine cloud returns an error.
        """
        check_type(headers, dict)

        if headers is not None:
            pass

        with_custom_headers = False
        _headers = self._session.headers or {}
        if headers:
            _headers.update(dict_of_str(headers))
            with_custom_headers = True
        check_type(hostname, basestring,
                   may_be_none=False)

        _params = {
        }
        _params.update(query_parameters)
        _params = dict_from_items_with_values(_params)

        path_params = {
            'hostname': hostname,
        }

        e_url = ('/api/v1/profile/{hostname}')
        endpoint_full_url = apply_path_params(e_url, path_params)
        if with_custom_headers:
            _api_response = self._session.get(endpoint_full_url, params=_params,
                                              headers=_headers)
        else:
            _api_response = self._session.get(endpoint_full_url, params=_params)

        return self._object_factory('bpm_bfa308ed7b5fb6acde734f6267b4e3_v3_1_1', _api_response)

    def set_profiler_probe_config(self,
                                  hostname,
                                  active_directory=None,
                                  dhcp=None,
                                  dhcp_span=None,
                                  dns=None,
                                  http=None,
                                  netflow=None,
                                  nmap=None,
                                  pxgrid=None,
                                  radius=None,
                                  snmp_query=None,
                                  snmp_trap=None,
                                  headers=None,
                                  payload=None,
                                  active_validation=True,
                                  **query_parameters):
        """This API updates the profiler probe configuration of a PSN.  Set
        probe value as  null  to disable probe.  Ex: Below
        payload will disable NMAP, PxGrid and SNMPTRAP probes  {
        "activeDirectory": { "daysBeforeRescan": 1 },    "dhcp":
        { "interfaces": "[{"interface":"GigabitEthernet 0"}]",
        "port": 0 },    "dhcpSpan": { "interfaces":
        "[{"interface":"GigabitEthernet 0"}]" },    "dns": {
        "timeout": 2 },    "http": { "interfaces":
        "[{"interface":"GigabitEthernet 0"}]" },    "netflow": {
        "interfaces": "[{"interface":"GigabitEthernet 0"}]",
        "port": 0 },    "nmap":  null ,    "pxgrid":  null ,
        "radius": [],    "snmpQuery": { "eventTimeout": 30,
        "retries": 2, "timeout": 1000 },    "snmpTrap":  null
        }  .

        Args:
            active_directory(object): The Active Directory probe
                queries the Active Directory for Windows
                information., property of the request
                body.
            dhcp(object): The DHCP probe listens for DHCP packets
                from IP helpers., property of the
                request body.
            dhcp_span(object): The DHCP SPAN probe collects DHCP
                packets., property of the request body.
            dns(object): The DNS probe performs a DNS lookup for the
                FQDN., property of the request body.
            http(object): The HTTP probe receives and parses HTTP
                packets., property of the request body.
            netflow(object): The NetFlow probe collects the NetFlow
                packets that are sent to it from
                routers., property of the request body.
            nmap(list): The NMAP probe scans endpoints for open
                ports and OS., property of the request
                body (list of objects).
            pxgrid(list): The pxGrid probe fetches attributes of MAC
                address or IP address as a subscriber
                from the pxGrid queue., property of the
                request body (list of objects).
            radius(list): The RADIUS probe collects RADIUS session
                attributes as well as CDP, LLDP, DHCP,
                HTTP, and MDM attributes from IOS
                Sensors., property of the request body
                (list of objects).
            snmp_query(object): The SNMP query probe collects
                details from network devices such as
                interface, CDP, LLDP, and ARP., property
                of the request body.
            snmp_trap(object): The SNMP trap probe receives linkup,
                linkdown, and MAC notification traps
                from network devices., property of the
                request body.
            hostname(basestring): hostname path parameter. Hostname
                of the node.
            headers(dict): Dictionary of HTTP Headers to send with the Request
                .
            payload(dict): A JSON serializable Python object to send in the
                body of the Request.
            active_validation(bool): Enable/Disable payload validation.
                Defaults to True.
            **query_parameters: Additional query parameters (provides
                support for parameters that may be added in the future).

        Returns:

            RestResponse: REST response with following properties:

              - headers(MyDict): response headers.
              - response(MyDict): response body as a MyDict object. Access the object's properties by using the dot notation
                or the bracket notation.
              - content(bytes): representation of the request's response
              - text(str): representation of the request's response

        Raises:
            TypeError: If the parameter types are incorrect.
            MalformedRequest: If the request body created is invalid.
            ApiError: If the Identity Services Engine cloud returns an error.
        """
        check_type(headers, dict)

        if headers is not None:
            pass

        with_custom_headers = False
        _headers = self._session.headers or {}
        if headers:
            _headers.update(dict_of_str(headers))
            with_custom_headers = True
        is_xml_payload = 'application/xml' in _headers.get('Content-Type', [])
        if active_validation and is_xml_payload:
            check_type(payload, basestring)
        if active_validation and not is_xml_payload:
            check_type(payload, dict)
        check_type(hostname, basestring,
                   may_be_none=False)

        _params = {
        }
        _params.update(query_parameters)
        _params = dict_from_items_with_values(_params)

        path_params = {
            'hostname': hostname,
        }
        if is_xml_payload:
            _payload = payload
        else:
            _payload = {
                'activeDirectory':
                    active_directory,
                'dhcp':
                    dhcp,
                'dhcpSpan':
                    dhcp_span,
                'dns':
                    dns,
                'http':
                    http,
                'netflow':
                    netflow,
                'nmap':
                    nmap,
                'pxgrid':
                    pxgrid,
                'radius':
                    radius,
                'snmpQuery':
                    snmp_query,
                'snmpTrap':
                    snmp_trap,
            }
            _payload.update(payload or {})
            _payload = dict_from_items_with_values(_payload)
        if active_validation and not is_xml_payload:
            self._request_validator('jsd_bba25b96ab6c5a99a7e7933a1ef71977_v3_1_1')\
                .validate(_payload)

        e_url = ('/api/v1/profile/{hostname}')
        endpoint_full_url = apply_path_params(e_url, path_params)

        request_params = {'data': _payload} if is_xml_payload else {'json': _payload}
        if with_custom_headers:
            _api_response = self._session.put(endpoint_full_url, params=_params,
                                              headers=_headers,
                                              **request_params)

        else:
            _api_response = self._session.put(endpoint_full_url, params=_params,
                                              **request_params)

        return self._object_factory('bpm_bba25b96ab6c5a99a7e7933a1ef71977_v3_1_1', _api_response)



# -*- coding: utf-8 -*-
"""Cisco Identity Services Engine Node Group API wrapper.

Copyright (c) 2021 Cisco and/or its affiliates.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


from __future__ import (
    absolute_import,
    division,
    print_function,
    unicode_literals,
)

from builtins import *

from past.builtins import basestring

from ...restsession import RestSession
from ...utils import (
    check_type,
    dict_from_items_with_values,
    apply_path_params,
    dict_of_str,
)
from ...pagination import get_next_page


class NodeGroup(object):
    """Identity Services Engine Node Group API (version: 3.0.0).

    Wraps the Identity Services Engine Node Group
    API and exposes the API as native Python
    methods that return native Python objects.

    APIs for the configuration, administration and monitoring of the nodes in an ISE cluster deployment.

    """

    def __init__(self, session, object_factory, request_validator):
        """Initialize a new NodeGroup
        object with the provided RestSession.

        Args:
            session(RestSession): The RESTful session object to be used for
                API calls to the Identity Services Engine service.

        Raises:
            TypeError: If the parameter types are incorrect.

        """
        check_type(session, RestSession)

        super(NodeGroup, self).__init__()

        self._session = session
        self._object_factory = object_factory
        self._request_validator = request_validator

    def get_node_groups(self,
                        headers=None,
                        **query_parameters):
        """Get details of all the node groups in the cluster. To detect
        node failure and to reset all URL-redirected sessions on
        the failed node, two or more Policy Service nodes can be
        placed in the same node group. When a node that belongs
        to a node group fails, another node in the same node
        group issues a Change of Authorization (CoA) for all
        URL-redirected sessions on the failed node.

        Args:
            headers(dict): Dictionary of HTTP Headers to send with the Request
                .
            **query_parameters: Additional query parameters (provides
                support for parameters that may be added in the future).

        Returns:

            RestResponse: REST response with following properties:

              - headers(MyDict): response headers.
              - response(MyDict): response body as a MyDict object. Access the object's properties by using the dot notation
                or the bracket notation.
              - content(bytes): representation of the request's response
              - text(str): representation of the request's response

        Raises:
            TypeError: If the parameter types are incorrect.
            MalformedRequest: If the request body created is invalid.
            ApiError: If the Identity Services Engine cloud returns an error.
        """
        check_type(headers, dict)

        if headers is not None:
            pass

        with_custom_headers = False
        _headers = self._session.headers or {}
        if headers:
            _headers.update(dict_of_str(headers))
            with_custom_headers = True

        _params = {
        }
        _params.update(query_parameters)
        _params = dict_from_items_with_values(_params)

        path_params = {
        }

        e_url = ('/api/v1/deployment/node-group')
        endpoint_full_url = apply_path_params(e_url, path_params)
        if with_custom_headers:
            _api_response = self._session.get(endpoint_full_url, params=_params,
                                              headers=_headers)
        else:
            _api_response = self._session.get(endpoint_full_url, params=_params)

        return self._object_factory('bpm_a0824f9a589c58cd8df522524cb550ad_v3_0_0', _api_response)

    def get_node_group(self,
                       node_group_name,
                       headers=None,
                       **query_parameters):
        """Get details of a node group in the cluster.

        Args:
            node_group_name(basestring): node-group-name path
                parameter. ID of the existing node
                group.
            headers(dict): Dictionary of HTTP Headers to send with the Request
                .
            **query_parameters: Additional query parameters (provides
                support for parameters that may be added in the future).

        Returns:

            RestResponse: REST response with following properties:

              - headers(MyDict): response headers.
              - response(MyDict): response body as a MyDict object. Access the object's properties by using the dot notation
                or the bracket notation.
              - content(bytes): representation of the request's response
              - text(str): representation of the request's response

        Raises:
            TypeError: If the parameter types are incorrect.
            MalformedRequest: If the request body created is invalid.
            ApiError: If the Identity Services Engine cloud returns an error.
        """
        check_type(headers, dict)

        if headers is not None:
            pass

        with_custom_headers = False
        _headers = self._session.headers or {}
        if headers:
            _headers.update(dict_of_str(headers))
            with_custom_headers = True
        check_type(node_group_name, basestring,
                   may_be_none=False)

        _params = {
        }
        _params.update(query_parameters)
        _params = dict_from_items_with_values(_params)

        path_params = {
            'node-group-name': node_group_name,
        }

        e_url = ('/api/v1/deployment/node-group/{node-group-name}')
        endpoint_full_url = apply_path_params(e_url, path_params)
        if with_custom_headers:
            _api_response = self._session.get(endpoint_full_url, params=_params,
                                              headers=_headers)
        else:
            _api_response = self._session.get(endpoint_full_url, params=_params)

        return self._object_factory('bpm_a0aadd33595645bf671efc4912f89a_v3_0_0', _api_response)

    def create_node_group(self,
                          node_group_name,
                          description=None,
                          mar_cache=None,
                          headers=None,
                          payload=None,
                          active_validation=True,
                          **query_parameters):
        """Developers need to create node group in the system.Node Group is
        a group of PSNs, mainly used for terminating posture
        pending sessions when a PSN in local node group
        fails.Node group members can communicate over TCP/7800.

        Args:
            description(string): description, property of the
                request body. Constraints: maxLength set
                to 256 and minLength set to 1.
            mar_cache(object): mar-cache, property of the request
                body.
            node_group_name(basestring): node-group-name path
                parameter. ID of the existing node
                group.
            headers(dict): Dictionary of HTTP Headers to send with the Request
                .
            payload(dict): A JSON serializable Python object to send in the
                body of the Request.
            active_validation(bool): Enable/Disable payload validation.
                Defaults to True.
            **query_parameters: Additional query parameters (provides
                support for parameters that may be added in the future).

        Returns:

            RestResponse: REST response with following properties:

              - headers(MyDict): response headers.
              - response(MyDict): response body as a MyDict object. Access the object's properties by using the dot notation
                or the bracket notation.
              - content(bytes): representation of the request's response
              - text(str): representation of the request's response

        Raises:
            TypeError: If the parameter types are incorrect.
            MalformedRequest: If the request body created is invalid.
            ApiError: If the Identity Services Engine cloud returns an error.
        """
        check_type(headers, dict)

        if headers is not None:
            pass

        with_custom_headers = False
        _headers = self._session.headers or {}
        if headers:
            _headers.update(dict_of_str(headers))
            with_custom_headers = True
        is_xml_payload = 'application/xml' in _headers.get('Content-Type', [])
        if active_validation and is_xml_payload:
            check_type(payload, basestring)
        if active_validation and not is_xml_payload:
            check_type(payload, dict)
        check_type(node_group_name, basestring,
                   may_be_none=False)

        _params = {
        }
        _params.update(query_parameters)
        _params = dict_from_items_with_values(_params)

        path_params = {
            'node-group-name': node_group_name,
        }
        if is_xml_payload:
            _payload = payload
        else:
            _payload = {
                'description':
                    description,
                'mar-cache':
                    mar_cache,
            }
            _payload.update(payload or {})
            _payload = dict_from_items_with_values(_payload)
        if active_validation and not is_xml_payload:
            self._request_validator('jsd_f41d844dbee15f7680920652004f69b6_v3_0_0')\
                .validate(_payload)

        e_url = ('/api/v1/deployment/node-group/{node-group-name}')
        endpoint_full_url = apply_path_params(e_url, path_params)

        request_params = {'data': _payload} if is_xml_payload else {'json': _payload}
        if with_custom_headers:
            _api_response = self._session.post(endpoint_full_url, params=_params,
                                               headers=_headers,
                                               **request_params)
        else:
            _api_response = self._session.post(endpoint_full_url, params=_params,
                                               **request_params)

        return self._object_factory('bpm_f41d844dbee15f7680920652004f69b6_v3_0_0', _api_response)

    def update_node_group(self,
                          node_group_name,
                          description=None,
                          mar_cache=None,
                          headers=None,
                          payload=None,
                          active_validation=True,
                          **query_parameters):
        """API updates an existing node group in the system.

        Args:
            description(string): description, property of the
                request body. Constraints: maxLength set
                to 256 and minLength set to 1.
            mar_cache(object): mar-cache, property of the request
                body.
            node_group_name(basestring): node-group-name path
                parameter. ID of the existing node
                group.
            headers(dict): Dictionary of HTTP Headers to send with the Request
                .
            payload(dict): A JSON serializable Python object to send in the
                body of the Request.
            active_validation(bool): Enable/Disable payload validation.
                Defaults to True.
            **query_parameters: Additional query parameters (provides
                support for parameters that may be added in the future).

        Returns:

            RestResponse: REST response with following properties:

              - headers(MyDict): response headers.
              - response(MyDict): response body as a MyDict object. Access the object's properties by using the dot notation
                or the bracket notation.
              - content(bytes): representation of the request's response
              - text(str): representation of the request's response

        Raises:
            TypeError: If the parameter types are incorrect.
            MalformedRequest: If the request body created is invalid.
            ApiError: If the Identity Services Engine cloud returns an error.
        """
        check_type(headers, dict)

        if headers is not None:
            pass

        with_custom_headers = False
        _headers = self._session.headers or {}
        if headers:
            _headers.update(dict_of_str(headers))
            with_custom_headers = True
        is_xml_payload = 'application/xml' in _headers.get('Content-Type', [])
        if active_validation and is_xml_payload:
            check_type(payload, basestring)
        if active_validation and not is_xml_payload:
            check_type(payload, dict)
        check_type(node_group_name, basestring,
                   may_be_none=False)

        _params = {
        }
        _params.update(query_parameters)
        _params = dict_from_items_with_values(_params)

        path_params = {
            'node-group-name': node_group_name,
        }
        if is_xml_payload:
            _payload = payload
        else:
            _payload = {
                'description':
                    description,
                'mar-cache':
                    mar_cache,
            }
            _payload.update(payload or {})
            _payload = dict_from_items_with_values(_payload)
        if active_validation and not is_xml_payload:
            self._request_validator('jsd_a99695fd5ee0b00efce79a5761ff_v3_0_0')\
                .validate(_payload)

        e_url = ('/api/v1/deployment/node-group/{node-group-name}')
        endpoint_full_url = apply_path_params(e_url, path_params)

        request_params = {'data': _payload} if is_xml_payload else {'json': _payload}
        if with_custom_headers:
            _api_response = self._session.put(endpoint_full_url, params=_params,
                                              headers=_headers,
                                              **request_params)

        else:
            _api_response = self._session.put(endpoint_full_url, params=_params,
                                              **request_params)

        return self._object_factory('bpm_a99695fd5ee0b00efce79a5761ff_v3_0_0', _api_response)

    def delete_node_group(self,
                          node_group_name,
                          headers=None,
                          **query_parameters):
        """Developers need to delete node group in the system.

        Args:
            node_group_name(basestring): node-group-name path
                parameter. ID of the existing node
                group.
            headers(dict): Dictionary of HTTP Headers to send with the Request
                .
            **query_parameters: Additional query parameters (provides
                support for parameters that may be added in the future).

        Returns:

            RestResponse: REST response with following properties:

              - headers(MyDict): response headers.
              - response(MyDict): response body as a MyDict object. Access the object's properties by using the dot notation
                or the bracket notation.
              - content(bytes): representation of the request's response
              - text(str): representation of the request's response

        Raises:
            TypeError: If the parameter types are incorrect.
            MalformedRequest: If the request body created is invalid.
            ApiError: If the Identity Services Engine cloud returns an error.
        """
        check_type(headers, dict)

        if headers is not None:
            pass

        with_custom_headers = False
        _headers = self._session.headers or {}
        if headers:
            _headers.update(dict_of_str(headers))
            with_custom_headers = True
        check_type(node_group_name, basestring,
                   may_be_none=False)

        _params = {
        }
        _params.update(query_parameters)
        _params = dict_from_items_with_values(_params)

        path_params = {
            'node-group-name': node_group_name,
        }

        e_url = ('/api/v1/deployment/node-group/{node-group-name}')
        endpoint_full_url = apply_path_params(e_url, path_params)
        if with_custom_headers:
            _api_response = self._session.delete(endpoint_full_url, params=_params,
                                                 headers=_headers)
        else:
            _api_response = self._session.delete(endpoint_full_url, params=_params)

        return self._object_factory('bpm_c5c37c343c050e0af67b2223e64faf3_v3_0_0', _api_response)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['ciscoisesdk',
 'ciscoisesdk.api',
 'ciscoisesdk.api.v3_0_0',
 'ciscoisesdk.api.v3_1_0',
 'ciscoisesdk.api.v3_1_1',
 'ciscoisesdk.models',
 'ciscoisesdk.models.validators',
 'ciscoisesdk.models.validators.v3_0_0',
 'ciscoisesdk.models.validators.v3_1_0',
 'ciscoisesdk.models.validators.v3_1_1']

package_data = \
{'': ['*']}

install_requires = \
['fastjsonschema>=2.14.5,<3.0.0',
 'future>=0.18.2,<0.19.0',
 'requests-toolbelt>=0.9.1,<0.10.0',
 'requests>=2.25.1,<3.0.0',
 'xmltodict==0.12.0']

setup_kwargs = {
    'name': 'ciscoisesdk',
    'version': '1.5.0',
    'description': 'Cisco Identity Services Engine Platform SDK',
    'long_description': '=============\nciscoisesdk\n=============\n\n**ciscoisesdk** is a *community developed* Python library for working with the Identity Services Engine APIs. \nOur goal is to make working with Cisco Identity Services Engine in Python a *native* and *natural* experience!\n\n.. code-block:: python\n\n    from ciscoisesdk import IdentityServicesEngineAPI\n    from ciscoisesdk.exceptions import ApiError\n\n    # Create a IdentityServicesEngineAPI connection object;\n    # it uses ISE custom URL, username, and password, with ISE API version 3.1.1\n    # and its API Gateway enabled,\n    # verify=True to verify the server\'s TLS certificate\n    # with debug logs disabled\n    # and without using the CSRF token\n    api = IdentityServicesEngineAPI(username=\'admin\',\n                                    password=\'C1sco12345\',\n                                    uses_api_gateway=True,\n                                    base_url=\'https://198.18.133.27\',\n                                    version=\'3.1.1\',\n                                    verify=True,\n                                    debug=False,\n                                    uses_csrf_token=False)\n    # NOTE: This collection assumes that the ERS APIs and OpenAPIs are enabled.\n\n    # Get allowed protocols (first page)\n    search_result = api.allowed_protocols.get_all().response.SearchResult\n    if search_result and search_result.resources:\n      for resource in search_result.resources:\n        resource_detail = api.allowed_protocols.get_by_id(\n                            resource.id\n                          ).response.AllowedProtocols\n        print("Id {}\\nName {}\\nallowChap {}\\n".format(resource_detail.id,\n                                                      resource_detail.name,\n                                                      resource_detail.allowChap))\n    print("----------")\n\n    # Handle pagination with a generator\n    allowed_protols_gen = api.allowed_protocols.get_all_generator()\n    for allowed_protocols_page_resp in allowed_protols_gen:\n      allowed_protols_result = allowed_protocols_page_resp.response.SearchResult\n      for resource in allowed_protols_result.resources:\n        resource_detail = api.allowed_protocols.get_by_id(\n                            resource.id\n                          ).response.AllowedProtocols\n        print("Id {}\\nName {}\\nallowChap {}\\n".format(resource_detail.id,\n                                                      resource_detail.name,\n                                                      resource_detail.allowChap))\n\n    # Create network device\n    try:\n        network_device_response = api.network_device.create(\n                                    name=\'ISE_EST_Local_Host_19\',\n                                    network_device_iplist=[{"ipaddress": "127.35.0.1", "mask": 32}])\n        print("Created, new Location {}".format(network_device_response.headers.Location))\n    except ApiError as e:\n        print(e)\n\n    # Filter network device\n    device_list_response = api.network_device.get_all(filter=\'name.EQ.ISE_EST_Local_Host_19\')\n    device_responses = device_list_response.response.SearchResult.resources\n    if len(device_responses) > 0:\n        device_response = device_responses[0]\n\n        # Get network device detail\n        device_response_detail = api.network_device.get_by_id(device_response.id).response.NetworkDevice\n\n    # Advance usage example using Custom Caller functions\n    ## Define a Custom caller named function\n    ## Call them with:\n    ##    get_created_result(network_device_response.headers.Location)\n    def get_created_result(location):\n        return api.custom_caller.call_api(\'GET\', location)\n\n    ## Define the get_created_result function\n    ## under the custom_caller wrapper.\n    ## Call them with:\n    ##    api.custom_caller.get_created_result(network_device_response.headers.Location)\n    def setup_custom():\n        api.custom_caller.add_api(\'get_created_result\',\n                                    lambda location:\n                                    api.custom_caller.call_api(\'GET\', location)\n                                  )\n\n    # Add the custom API calls to the connection object under the custom_caller wrapper\n    setup_custom()\n\n    # Call the newly added functions\n    created_device_1 = get_created_result(network_device_response.headers.Location)\n    created_device_2 = api.custom_caller.get_created_result(network_device_response.headers.Location)\n    print(created_device_1.response == created_device_2.response)\n\n    if len(device_responses) > 0:\n        device_response = device_responses[0]\n\n        # Delete network device\n        delete_device = api.network_device.delete_by_id(device_response.id)\n\n\n\nIntroduction_\n\n\nInstallation\n------------\n\nInstalling and upgrading ciscoisesdk is easy:\n\n**Install via PIP**\n\n.. code-block:: bash\n\n    $ pip install ciscoisesdk\n\n**Upgrading to the latest Version**\n\n.. code-block:: bash\n\n    $ pip install ciscoisesdk --upgrade\n\n\nDocumentation\n-------------\n\n**Excellent documentation is now available at:**\nhttps://ciscoisesdk.readthedocs.io\n\nCheck out the Quickstart_ to dive in and begin using ciscoisesdk.\n\n\nRelease Notes\n-------------\n\nPlease see the releases_ page for release notes on the incremental functionality and bug fixes incorporated into the published releases.\n\n\nQuestions, Support & Discussion\n-------------------------------\n\nciscoisesdk is a *community developed* and *community supported* project.  If you experience any issues using this package, please report them using the issues_ page.\n\n\nContribution\n------------\n\nciscoisesdk_ is a community development projects.  Feedback, thoughts, ideas, and code contributions are welcome!  Please see the `Contributing`_ guide for more information.\n\n\nInspiration\n------------\n\nThis library is inspired by the webexteamssdk_  library\n\nChange log\n----------\n\nAll notable changes to this project will be documented in the CHANGELOG_ file.\n\nThe development team may make additional name changes as the library evolves with the ISE APIs.\n\n\n*Copyright (c) 2021 Cisco and/or its affiliates.*\n\n.. _Introduction: https://ciscoisesdk.readthedocs.io/en/latest/api/intro.html\n.. _ciscoisesdk.readthedocs.io: https://ciscoisesdk.readthedocs.io\n.. _Quickstart: https://ciscoisesdk.readthedocs.io/en/latest/api/quickstart.html\n.. _ciscoisesdk: https://github.com/CiscoISE/ciscoisesdk\n.. _issues: https://github.com/CiscoISE/ciscoisesdk/issues\n.. _pull requests: https://github.com/CiscoISE/ciscoisesdk/pulls\n.. _releases: https://github.com/CiscoISE/ciscoisesdk/releases\n.. _the repository: ciscoisesdk_\n.. _pull request: `pull requests`_\n.. _Contributing: https://github.com/CiscoISE/ciscoisesdk/blob/master/docs/contributing.rst\n.. _webexteamssdk: https://github.com/CiscoDevNet/webexteamssdk\n.. _CHANGELOG: https://github.com/CiscoISE/ciscoisesdk/blob/main/CHANGELOG.md\n',
    'author': 'Jose Bogarin Solano',
    'author_email': 'jbogarin@altus.cr',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://ciscoisesdk.readthedocs.io/en/latest/',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
